@@ -27,7 +27,7 @@ from pythainer.sysutils import (
 )
 
 
-def _generate_dockerfile_content(
+def render_dockerfile_content(
     package_manager: str,
     commands: List[DockerBuildCommand],
 ) -> str:
@@ -78,6 +78,19 @@ class PartialDockerBuilder:
         result_builder._extend(other=other)
         return result_builder
 
+    def __ior__(self, other: "PartialDockerBuilder") -> "PartialDockerBuilder":
+        """
+        In-place merge of another PartialDockerBuilder into this one.
+
+        Parameters:
+            other (PartialDockerBuilder): The other builder to merge into this one.
+
+        Returns:
+            PartialDockerBuilder: The current builder with commands from the other merged in.
+        """
+        self._extend(other=other)
+        return self
+
     def _extend(self, other: "PartialDockerBuilder") -> None:
         """
         Extends the current builder's commands with those from another builder.
@@ -207,6 +220,17 @@ class PartialDockerBuilder:
         """
         self._build_commands.append(AddPkgDockerBuildCommand(packages=packages))
 
+    def copy(self, filename: PathType, destination: PathType) -> None:
+        """
+        Copies a file to the docker container
+
+        Parameters:
+            filename (PathType): The file to copy to the container.
+            destination (PathType): The location to place the file within the Docker container.
+        """
+        cmd = f"COPY {filename} {destination}"
+        self._build_commands.append(StrDockerBuildCommand(cmd))
+
 
 class DockerBuilder(PartialDockerBuilder):
     """
@@ -244,14 +268,14 @@ class DockerBuilder(PartialDockerBuilder):
         Parameters:
             dockerfile_paths (List[PathType]): A list of paths where the Dockerfile should be saved.
         """
-        dockerfile_content = _generate_dockerfile_content(
+        dockerfile_content = render_dockerfile_content(
             package_manager=self._package_manager,
             commands=self._build_commands,
         )
 
         all_dockerfile_paths = dockerfile_paths + [
             "/tmp/Dockerfile",
-            "/tmp/benchkit/docker/latest/Dockerfile",
+            "/tmp/pythainer/docker/latest/Dockerfile",
         ]
 
         for dockerfile_path in all_dockerfile_paths:
@@ -294,9 +318,14 @@ class DockerBuilder(PartialDockerBuilder):
         if gid is not None:
             build_args.append(f"--build-arg=GID={gid}")
 
+        docker_path = shell_out(
+            command=["which", "docker"],
+            output_is_log=False,
+        )
+
         command = (
             [
-                "docker",
+                docker_path,
                 "build",
                 "--file",
                 f"{dockerfile_path}",
@@ -312,7 +341,7 @@ class DockerBuilder(PartialDockerBuilder):
 
     def generate_build_script(
         self,
-        output_path: PathType = "/tmp/benchkit/docker/latest/docker-build.sh",
+        output_path: PathType = "/tmp/pythainer/docker/latest/docker-build.sh",
     ) -> None:
         """
         Generates a shell script to execute the Docker build commands.
@@ -353,17 +382,18 @@ class DockerBuilder(PartialDockerBuilder):
         with open(output_path, "w") as script_file:
             script_file.write(file_content)
 
-    def build(self, dockerfile_savepath: PathType = "") -> None:
+    def build(self, dockerfile_savepath: PathType = "", docker_context: PathType = "") -> None:
         """
         Builds the Docker image using the generated Dockerfile and specified Docker build directory.
 
         Parameters:
             dockerfile_savepath (PathType): Optional path to save the Dockerfile used for the build.
+            docker_context (PathType): Optional path to save the Docker context used for the build.
         """
-        main_dir = Path("/tmp/benchkit/docker/")
+        main_dir = Path("/tmp/pythainer/docker/")
         mkdir(main_dir)
         with tempfile.TemporaryDirectory(
-            prefix="/tmp/benchkit/docker/docker-build-",
+            prefix="/tmp/pythainer/docker/docker-build-",
             dir=main_dir,
         ) as temp_dir:
             temp_path = Path(temp_dir)
@@ -375,7 +405,7 @@ class DockerBuilder(PartialDockerBuilder):
 
             command = self.get_build_commands(
                 dockerfile_path=dockerfile_path,
-                docker_build_dir=temp_path,
+                docker_build_dir=Path(docker_context).resolve() if docker_context else temp_path,
                 uid=get_uid(),
                 gid=get_gid(),
             )
@@ -389,7 +419,10 @@ class DockerBuilder(PartialDockerBuilder):
                 output_is_log=True,
             )
 
-    def get_runner(self) -> ConcreteDockerRunner:
+    def get_runner(
+        self,
+        workdir: PathType | None = None,
+    ) -> ConcreteDockerRunner:
         """
         Returns a concrete runner using the image built in the current builder.
         This runner might be immediately used.
@@ -400,6 +433,7 @@ class DockerBuilder(PartialDockerBuilder):
         return ConcreteDockerRunner(
             image=self._tag,
             name=self._tag,
+            workdir=workdir,
         )
 
     def __or__(
@@ -452,7 +486,16 @@ class UbuntuDockerBuilder(DockerBuilder):
         Runs the 'unminimize' command to restore an Ubuntu image to its full version,
         undoing the 'minimize' effect.
         """
-        self.run(command="yes | unminimize")
+        # only install if "unminimize" package is present:
+        self.run_multiple(
+            commands=[
+                "apt-get update",
+                "((apt-cache show unminimize && apt-get install -y unminimize) || true)",
+                "rm -rf /var/lib/apt/lists/*",
+            ]
+        )
+
+        self.run(command="if which unminimize; then yes | unminimize; fi")
 
     def remove_group_if_gid_exists(self, gid: str) -> None:
         """
@@ -543,10 +586,11 @@ class DockerfileDockerBuilder(DockerBuilder):
 
     def generate_build_script(
         self,
-        output_path: PathType = "/tmp/benchkit/docker/latest/docker-build.sh",
+        output_path: PathType = "/tmp/pythainer/docker/latest/docker-build.sh",
     ) -> None:
         raise NotImplementedError()
 
+    # pylint: disable=arguments-differ
     def build(self, dockerfile_savepath: PathType = "") -> None:
         if dockerfile_savepath:
             raise NotImplementedError()
